<?php

namespace Luticate\Auth\Business;

use Luticate\Utils\LuBusiness;
use Luticate\Auth\DataAccess\LuticateSettingsUsersDataAccess;
use Luticate\Auth\DBO\LuticateSettingsUsersDbo;
use Luticate\Utils\LuMultipleDbo;

class LuticateSettingsUsersBusiness extends LuBusiness {
    protected static function getDataAccess()
    {
        return new LuticateSettingsUsersDataAccess();
    }

    public static function checkSettingUserName($user_id, $setting_name)
    {
        LuticateUsersBusiness::checkUserId($user_id);
        LuticateSettingsBusiness::checkSettingName($setting_name);
        return LuticateSettingsUsersDataAccess::getByName($user_id, $setting_name);
    }

    public static function getAllByUser($user_id, $page = 0, $perPage = 2000000000)
    {
        return LuticateSettingsUsersDataAccess::getAllByUser($user_id, $page, $perPage);
    }

    public static function get($user_id, $setting_name)
    {
        return LuticateSettingsUsersDataAccess::getByName($user_id, $setting_name);
    }

    public static function add($user_id, $setting_name, $setting_value)
    {
        $setting = self::checkSettingUserName($user_id, $setting_name);
        if (!is_null($setting)) {
            self::badInput("User setting already exists");
        }
        $setting = new LuticateSettingsUsersDbo();
        $setting->setName($setting_name);
        $setting->setValue($setting_value);
        $setting->setUserId($user_id);
        LuticateSettingsUsersDataAccess::add($setting);
        return true;
    }

    public static function del($user_id, $setting_name)
    {
        self::checkSettingUserName($user_id, $setting_name);
        LuticateSettingsUsersDataAccess::delete($user_id, $setting_name);
        return true;
    }

    public static function edit($user_id, $setting_name, $setting_value)
    {
        self::del($user_id, $setting_name);
        return self::add($user_id, $setting_name, $setting_value);
    }
}